{% extends "site_base.html" %}

{% load i18n %}
{% load bootstrap_tags %}

{% block head_title %}Conference Schedule Edit{% endblock %}

{% block body_class %}full{% endblock %}

{% block right %}
{% endblock %}

{% block extra_head %}
    <link rel="stylesheet" href="{{ STATIC_URL }}chosen/chosen.css" />
    <style>
        .table td {
            font-size: 9pt;
        }
        .table th, td.slot {
            text-align: center;
            vertical-align: middle;
        }
        td.time {
            vertical-align: top;
            width: 50px;
            font-size: 8pt;
            padding-top: 0;
        }
        td.slot .title {
            font-weight: bold;
            line-height: 10pt;
        }
        #id_presentation {
            width:400px;
        }
    </style>
{% endblock %}

{% block body_outer %}
    <div class="row">
        <div class="span12">
            <h1>Schedule Edit</h1>
            
            {% for timetable in days %}
                <h2>{{ timetable.day.date }}</h2>
                {% include "schedule/_edit_grid.html" %}
            {% endfor %}
        </div>
        
        <div class="modal fade hide in" id="slotEditModal"></div>
    </div>
{% endblock %}

{% block extra_script %}
    <script src="{{ STATIC_URL }}chosen/chosen.jquery.min.js" type="text/javascript"></script>
    <script type="text/javascript">
        $(function() {
            $("a.edit-slot").click(function(e) {
                $("#slotEditModal").load($(this).data("action"), function() {
                    $("#id_presentation").chosen();
                    $("#slotEditModal").modal("show");
                });
                e.preventDefault();
            });
        });
    </script>
{% endblock %}
