{% load sitetree %}
{% if sitetree_items %}
    <ul class="breadcrumb">
        {% for item in sitetree_items %}
            {% if not forloop.last %}
                <li>
                    <a href="{% sitetree_url for item %}" {% if item.hint %}title="{{ item.hint }}"{% endif %}>{{ item.title_resolved }}</a>
                    <span class="divider">/</span>
                </li>
            {% else %}
                <li class="active">{{ item.title_resolved }}</li>
            {% endif %}
        {% endfor %}
    </ul>
{% else %}

{% endif %}
