<table class="table table-bordered table-condensed">
    <tr>
        <th>&nbsp;</th>
        {% for room in timetable.rooms %}
            <th>{{ room.name }}</th>
        {% endfor %}
    </tr>
    {% for row in timetable %}
        <tr>
            <td class="time">{{ row.time|date:"h:iA" }}</td>
            {% for slot in row.slots %}
                <td class="slot slot-{{ slot.kind.label }}" colspan="{{ slot.colspan }}" rowspan="{{ slow.rowspan }}">
                    {% if slot.kind.label == "talk" %}
                        {% if not slot.content %}
                            <a class="btn btn-mini edit-slot" data-action="{% url schedule_slot_edit schedule.section.slug slot.pk %}" href="#">+</a>
                        {% else %}
                            <div class="title"><a class="edit-slot" data-action="{% url schedule_slot_edit schedule.section.slug slot.pk %}" href="#">{{ slot.content.title }}</a></div>
                            <div class="speaker">{{ slot.content.speaker }}</div>
                        {% endif %}
                    {% else %}
                        {{ slot.kind.label }}
                    {% endif %}
                </td>
            {% endfor %}
        </tr>
    {% endfor %}
</table>