{% extends "reviews/base.html" %}

{% block body %}
    <h1>Access Not Permitted</h1>
    
    <p>
        Sorry, you do not have permission to access this page. If you 
        believe this is a bug, please contact us immediately.
    </p>
{% endblock %}
