{% load sitetree %}
{% if sitetree_items %}
<ul>
    {% for item in sitetree_items %}
        {% if item.insitetree  %}
            <li>
                <a href="{% sitetree_url for item %}" {% if item.hint %}title="{{ item.hint }}"{% endif %}>{{ item.title_resolved }}</a>
                {% if item.has_children %}
                    {% sitetree_children of item for sitetree template "sitetree/tree.html" %}
                {% endif %}
            </li>
        {% endif %}
    {% endfor %}
</ul>
{% endif %}
