{% extends "site_base.html" %}

{% load i18n %}
{% load bootstrap_tags %}
{% load boxes_tags %}

{% block head_title %}Conference Schedule{% endblock %}

{% block body_class %}full{% endblock %}

{% block right %}
{% endblock %}

{% block extra_head %}
    <style>
        .table td {
            font-size: 9pt;
        }
        .table th, td.slot {
            text-align: center;
            vertical-align: middle;
        }
        td.time {
            vertical-align: top;
            width: 50px;
            font-size: 8pt;
            padding-top: 0;
        }
        td.slot .title {
            font-weight: bold;
            line-height: 10pt;
        }
    </style>
{% endblock %}

{% block body_outer %}
    <div class="row">
        <div class="span12">
            <h1>Schedule</h1>
            
            {% box "schedule_top" %}
            
            {% for timetable in days %}
                <h2>{{ timetable.day.date }}</h2>
                {% include "schedule/_grid.html" %}
            {% endfor %}
        </div>
    </div>
{% endblock %}
