<p>{{ sponsor.name }} has applied to be a sponsor.</p>

<ul>
    <li><b>Applicant</b>: {{ sponsor.applicant }}</li>
    <li><b>Sponsor Name</b>: {{ sponsor.name }}</li>
    <li><b>Sponsor Contact</b>: {{ sponsor.contact_name }}</li>
    <li><b>Sponsor Contact Email</b>: {{ sponsor.contact_email }}</li>
    <li><b>Sponsorship Level</b>: {{ sponsor.level }}</li>
</ul>
